@@ -1,8 +1,10 @@
 """ python inspection/code generation API """
+from __future__ import absolute_import, division, print_function
 from .code import Code  # noqa
 from .code import ExceptionInfo  # noqa
 from .code import Frame  # noqa
 from .code import Traceback  # noqa
+from .code import filter_traceback  # noqa
 from .code import getrawcode  # noqa
 from .source import Source  # noqa
 from .source import compile_ as compile  # noqa
