@@ -676,7 +676,9 @@ class TerminalReporter(object):
 
         if fspath:
             res = mkrel(nodeid).replace("::()", "")  # parens-normalization
-            if nodeid.split("::")[0] != fspath.replace("\\", nodes.SEP):
+            if self.verbosity >= 2 and nodeid.split("::")[0] != fspath.replace(
+                "\\", nodes.SEP
+            ):
                 res += " <- " + self.startdir.bestrelpath(fspath)
         else:
             res = "[location]"
@@ -835,9 +837,7 @@ def repr_pythonversion(v=None):
 
 
 def build_summary_stats_line(stats):
-    keys = (
-        "failed passed skipped deselected " "xfailed xpassed warnings error"
-    ).split()
+    keys = ("failed passed skipped deselected xfailed xpassed warnings error").split()
     unknown_key_seen = False
     for key in stats.keys():
         if key not in keys:
